Struct reactor::Runtime

source ·
pub struct Runtime<H: Handler, P: Poll> { /* private fields */ }
Internal Reactor runtime which is run in a dedicated thread.

Use this structure direactly only if you’d like to have the full control over the reactor thread.

This runtime structure does not spawns a thread and is blocking. It implements the actual reactor event loop.

Implementations

Creates new reactor runtime using provided Poll engine and a service exposing Handler API to the reactor.

Provides a copy of a Controller object which exposes an API to the reactor and a service running inside of its thread.

See Handler::Command for the details.